@@ -38,7 +38,7 @@ class ToxTest(unittest.TestCase):
         for i in range(n):
             self.alice.do()
             self.bob.do()
-            sleep(interval / 1000.0)
+            sleep(interval / 2000.0)
 
     def loop_until_connected(self):
         """
@@ -187,6 +187,7 @@ class ToxTest(unittest.TestCase):
 
         MSG = 'Happy'
         AID = self.aid
+
         def on_status_message(self, friend_id, new_message):
             assert friend_id == AID
             assert new_message == MSG
@@ -350,9 +351,7 @@ class ToxTest(unittest.TestCase):
         t:on_friend_action
         t:on_friend_message
         t:send_action
-        t:send_action_withid
         t:send_message
-        t:send_message_withid
         """
         self.bob_add_alice_as_friend()
 
@@ -370,10 +369,6 @@ class ToxTest(unittest.TestCase):
         self.alice.fm = False
         assert self.wait_callback(self.alice, 'fm')
 
-        self.ensure_exec(self.bob.send_message_withid, (self.aid, 42, MSG))
-        self.alice.fm = False
-        assert self.wait_callback(self.alice, 'fm')
-
         AliceTox.on_friend_message = Tox.on_friend_message
 
         #: Test action
@@ -390,10 +385,6 @@ class ToxTest(unittest.TestCase):
         self.alice.fa = False
         assert self.wait_callback(self.alice, 'fa')
 
-        self.ensure_exec(self.bob.send_action_withid, (self.aid, 42, ACTION))
-        self.alice.fa = False
-        assert self.wait_callback(self.alice, 'fa')
-
         AliceTox.on_friend_action = Tox.on_friend_action
 
         #: Test delete friend
@@ -405,35 +396,13 @@ class ToxTest(unittest.TestCase):
         """
         t:on_read_receipt
         t:on_typing_change
-        t:set_send_receipts
         t:set_user_is_typing
         t:get_is_typing
         t:get_last_online
         """
         self.bob_add_alice_as_friend()
 
-        #: Test send receipts
         AID = self.aid
-        MSG = 'Hi, Bob!'
-
-        checked = {'checked': False, 'MID': 0}
-        def on_read_receipt(self, fid, receipt):
-            assert fid == AID
-            if not checked['checked']:
-                checked['checked'] = True
-                assert receipt == checked['MID']
-            self.rr = True
-
-        BobTox.on_read_receipt = on_read_receipt
-        self.bob.rr = False
-
-        self.bob.set_send_receipts(self.aid, True)
-        checked['MID'] = self.ensure_exec(self.bob.send_message,
-                (self.aid, MSG))
-        assert self.wait_callback(self.bob, 'rr')
-
-        self.bob.set_send_receipts(self.aid, False)
-        BobTox.on_read_receipt = Tox.on_read_receipt
 
         #: Test typing status
         def on_typing_change(self, fid, is_typing):
