@@ -476,30 +476,6 @@ ToxCore_send_message(ToxCore* self, PyObject* args)
   return PyLong_FromUnsignedLong(ret);
 }
 
-static PyObject*
-ToxCore_send_message_withid(ToxCore* self, PyObject* args)
-{
-  CHECK_TOX(self);
-
-  int friend_num = 0;
-  int length = 0;
-  uint32_t id = 0;
-  uint8_t* message = NULL;
-
-  if (!PyArg_ParseTuple(args, "iIs#", &friend_num, &id, &message, &length)) {
-    return NULL;
-  }
-
-  uint32_t ret = tox_send_message_withid(self->tox, friend_num, id,message,
-      length);
-  if (ret == 0) {
-    PyErr_SetString(ToxOpError, "failed to send message with id");
-    return NULL;
-  }
-
-  return PyLong_FromUnsignedLong(ret);
-}
-
 static PyObject*
 ToxCore_send_action(ToxCore* self, PyObject* args)
 {
@@ -522,30 +498,6 @@ ToxCore_send_action(ToxCore* self, PyObject* args)
   return PyLong_FromUnsignedLong(ret);
 }
 
-static PyObject*
-ToxCore_send_action_withid(ToxCore* self, PyObject* args)
-{
-  CHECK_TOX(self);
-
-  int friend_num = 0;
-  int length = 0;
-  uint32_t id = 0;
-  uint8_t* action = NULL;
-
-  if (!PyArg_ParseTuple(args, "iIs#", &friend_num, &id, &action, &length)) {
-    return NULL;
-  }
-
-  uint32_t ret = tox_send_action_withid(self->tox, friend_num, id, action,
-      length);
-  if (ret == 0) {
-    PyErr_SetString(ToxOpError, "failed to send action with id");
-    return NULL;
-  }
-
-  return PyLong_FromUnsignedLong(ret);
-}
-
 static PyObject*
 ToxCore_set_name(ToxCore* self, PyObject* args)
 {
@@ -834,23 +786,6 @@ ToxCore_get_is_typing(ToxCore* self, PyObject* args)
   }
 }
 
-static PyObject*
-ToxCore_set_send_receipts(ToxCore* self, PyObject* args)
-{
-  CHECK_TOX(self);
-
-  int friend_num = 0;
-  int yesno = 0;
-
-  if (!PyArg_ParseTuple(args, "ii", &friend_num, &yesno)) {
-    return NULL;
-  }
-
-  tox_set_sends_receipts(self->tox, friend_num, yesno);
-
-  Py_RETURN_NONE;
-}
-
 static PyObject*
 ToxCore_count_friendlist(ToxCore* self, PyObject* args)
 {
@@ -1650,22 +1585,11 @@ PyMethodDef Tox_methods[] = {
     "send_message(friend_number, message)\n"
     "Send a text chat message to an online friend."
   },
-  {
-    "send_message_withid", (PyCFunction)ToxCore_send_message_withid,
-    METH_VARARGS,
-    "send_message_withid(friend_number, id, message)\n"
-    "Send a text chat message to an online friend with id."
-  },
   {
     "send_action", (PyCFunction)ToxCore_send_action, METH_VARARGS,
     "send_action(friend_number, action)\n"
     "Send an action to an online friend."
   },
-  {
-    "send_action_withid", (PyCFunction)ToxCore_send_action_withid, METH_VARARGS,
-    "send_action_withid(friend_number, id, action)\n"
-    "Send an action to an online friend with id."
-  },
   {
     "set_name", (PyCFunction)ToxCore_set_name, METH_VARARGS,
     "set_name(name)\n"
@@ -1772,13 +1696,6 @@ PyMethodDef Tox_methods[] = {
     "get_is_typing(friend_number)\n"
     "Return True is user is typing.\n\n"
   },
-  {
-    "set_send_receipts", (PyCFunction)ToxCore_set_send_receipts,
-    METH_VARARGS,
-    "set_send_receipts(friend_number, yesno)\n"
-    "Sets whether we send read receipts for friendnumber. *yesno* should be "
-    "a boolean value."
-  },
   {
     "count_friendlist", (PyCFunction)ToxCore_count_friendlist,
     METH_NOARGS,
